@@ -145,13 +145,18 @@ class TestrepresentationViewSetClass:
     # ----- LIST ROUTE TEST ----- #
     #Test representationviewset "get": "list"
     def test_representationviewset(self):
-        request = APIRequestFactory().get("")
-        request.user = SuperUser.get_user()
-        vs = self.rmvs.as_view({"get": "list"})
-        response = vs(request)
-        assert response.status_code == status.HTTP_200_OK
-        assert response.data
-        print("\n- TestViewSetClass:test_representationviewset", colored("PASSED", 'green'))  
+        if self.factory is None:
+            print("- TestViewSetClass:test_representationviewset", colored("WARNING - factory not found for "+self.rmvs().get_serializer_class().Meta.model.__name__, 'yellow'))
+        else:
+            request = APIRequestFactory().get("")
+            request.user = SuperUser.get_user()
+            obj = self.factory()
+            kwargs = get_kwargs(obj, self.rmvs, request)
+            vs = self.rmvs.as_view({"get": "list"})
+            response = vs(request, **kwargs)
+            assert response.status_code == status.HTTP_200_OK
+            assert response.data
+            print("\n- TestViewSetClass:test_representationviewset", colored("PASSED", 'green'))  
 
     
     # ----- DETAIL ROUTE TEST ----- #
@@ -162,9 +167,10 @@ class TestrepresentationViewSetClass:
         else:
             request = APIRequestFactory().get("")
             request.user = SuperUser.get_user()
-            vs = self.rmvs.as_view({"get": "retrieve"})
             obj = self.factory()
-            response = vs(request, pk=obj.pk)
+            kwargs = get_kwargs(obj, self.rmvs, request)
+            vs = self.rmvs.as_view({"get": "retrieve"})
+            response = vs(request, **kwargs, pk=obj.pk)
             assert response.status_code == status.HTTP_200_OK
             assert response.data.get('instance')
             print("- TestViewSetClass:test_instancerepresentationviewset", colored("PASSED", 'green')) 
